## 0.4.4 - 2023-02-03

### Refactored

- [#683](https://github.com/edgarrmondragon/citric/issues/683) Use `pathlib.Path` where possible
- [#687](https://github.com/edgarrmondragon/citric/issues/687) Use a dedicated `RPCInterfaceNotEnabledError` exception when a disabled JSON Interface is detected
